#ifndef CSYNCD_H
#define CSYNCD_H

/* Limits and Constants */
#define MAX_PAYLOAD_SIZE 256     /* Max size in bytes of packet data */
#define STARTNET_RETRY_WAIT 60   /* Time to sleep in sec between start_network
				    retries -- should really be about 600 */

#define L_PORT 1313
#define R_PORT 1314
#define RESET_PORT 1315

#define SYNC_TIME 5  /* sleep this long between sync runs */

/* Data types */
#define D_INVALID	0
#define D_ARP		1	/* ARP data */
#define D_TCP		2	/* TCP data - Phase II */
#define D_UDP		3	/* UDP data - Phase II */
#define D_RAW		4	/* RAW data - Phase II */
#define D_SOCKSTAT	5	/* Socket state data - Phase II */
#define D_IPAUTOFW	6	/* Firewall autoforwarding */
#define D_IPFWD		7	/* Firewall forwarding rules */
#define D_ROUTE		8	/* Routing table */

/* Operations */
#define OP_INVALID	0
#define OP_ADD		1	/* Add entry to table */
#define OP_REMOVE	2	/* Remove entry from table */
#define OP_FLUSH	3	/* Flush contents of table */
#define OP_ACK		4	/* Ack - operation successful */
#define OP_NAK		5	/* Nak - operation failed */
#define OP_BOOTSTRAP	6	/* Passive: configure IP and start listening */
#define OP_RECONFIG	7	/* Passive: reread EEPROM & restart */

#define MODE_ACTIVE 	0
#define MODE_PASSIVE	1

/* Our packet info - this will be the contents of the UDP data section */
typedef struct {
	char datatype;
	char oper;
	unsigned char msg[MAX_PAYLOAD_SIZE];
} syncpkt_t;

/* And one of these will be the contents of the syncpkt_t msg section */
/* Info for the ARP table */
typedef struct {
	unsigned ipaddr,hwtype,flags;
	char hwaddr[32];
	unsigned mask;
	char dev[10];
} arp_data_t;

/* Info for the routing table */
typedef struct {
	char dev[10];
	int dest,gw,flags,refcnt,use,metric,mask,mtu,window,irtt;
} route_data_t;

/* Info for ip_forward table */
typedef struct {
	long saddr,smask,daddr,dmask;
	char vianame[20];
	long via_addr;
	int flags;
	int nsp,ndp;
	long pcnt,bcnt;
	int ports[10];
	int tosand, tosxor;
} ipfwd_data_t;

/* Info for ip_autofw table */
typedef struct {
	int type,proto,low,high,visible,hidden;
	long where,lastcontact;
	int ctlproto,ctlport;
	long timer_exp;
	int flags;
} ipautofw_data_t;

/* Boot time info */
typedef struct {
	unsigned eth0_ip;
	unsigned eth1_ip,eth1_mask,eth1_bcast;
} ipcfg_data_t;

/* Bring in the function protos */
#include "protos.h"

#endif /* CSYNCD_H */
