/* File: znodelist.h
 * Desc: Definitions for CardServices nodelist structures (and related junk)
 * Auth: San Mehat
 * Note:
 */                                           

typedef struct node_statistics
	{
	unsigned int UI_memfree;     /* Free memory on slave       */
	unsigned int UI_memtotal;    /* Total memory on slave      */
	unsigned int UI_temperature; /* Current slave temperature  */
	unsigned int UI_cpuload;     /* Current cpu load * 100     */
	} Z_STATS;

typedef struct zaphod_node
	{
	int          I_nodenum;      /* Node number for this slave   */
	unsigned int UI_ipaddr;      /* IP address (for send_ll_nak) */
	unsigned int UI_afptstamp;   /* Time of last AFP request     */
	Z_STATS      ZS_stats;       /* Slave statistics             */

	int					 hwflags;
#define HW_NO_NODE				0x00	/* Node not installed */
#define HW_NODE_OK				0x01	/* Node responding OK to the MPU */
#define HW_NODE_DEAD			0x02	/* Node not responding to the MPU */
#define HW_NODE_POWER_OFF 0x03	/* Node has no power */
#define	HW_CHANGE_FLAG		0x80000000	/*flag to the hi level a change */

	int          flags;          /* GP flags                     */
#define FLAG_INST 0x1          /* Slave insertion status       */
#define FLAG_POWR 0x2          /* Slave power status           */
#define FLAG_ENAB 0x4          /* Slave enabled for processing */
#define FLAG_FAIL 0x8          /* Slave hard-failure indicator */
#define FLAG_SENT 0x10				 /* AFP request outstanding      */
#define FLAG_POLL 0x20         /* OK to send AFP requests      */
#define FLAG_CONF 0x40         /* Node configured OK           */

	unsigned int UI_failcount;   /* Timeout / Failure Counter    */
	/* 
		This structure is used to set an alarm for a particular event.
 		Sometimes, there are events that should follow one another 
		within a certain period of time. The 'operations' are defined
		below.
	 */
	struct 
		{
		int				 I_operation;    /* Current slave 'operation'    */
		unsigned int UI_alarmtime; /* The time we should fail op   */
		} phase;
	struct zaphod_node *next;    /* Pointer to next node         */
	} Z_NODE;


#define PHASE_NO_POWER 0 /*
												  Slot has no power. Expect at the startup.
												 */
#define PHASE_NO_POWER_TIMEOUT 5

#define PHASE_POWERUP 1 /*
												  Slot has been powered up, and slave
													should be booting. Timeout for this
													operation is 15 seconds. If a timeout
													occurs, we reboot the slave and try
													again
												 */
#define PHASE_POWERUP_TIMEOUT 15

#define PHASE_CONFIG  2	/* 
													Slave has been sent the configuration
													and should be mounting its fs's, and
													starting webservers. Timeout for this
													is 15 seconds. If a timeout occurs,
													we assume the slave has crashed or
													otherwise died/hungup. 
											   */
#define PHASE_CONFIG_TIMEOUT 15

#define PHASE_IDLE		3 /*
													Slave is currently inbetween AFP STATUS
													requests. The alarm is used to trigger
													a new AFP STATUS request and a phase
													transition into the PHASE_STATUS phase.
												 */
#define PHASE_IDLE_TIMEOUT 1

#define PHASE_STATUS	4 /* 
													Slave has been sent an AFP STATUS request,
												  and should be returning status and
												  statistics information. The timeout for
												  this is 2 seconds. If a
												  timeout occurs, we up the node error count.
												 */
#define PHASE_STATUS_TIMEOUT 2

#define PHASE_RESET	  5 /* 
													Slave has been sent a RESET request and
													should be stopping all webservers, unmounting
													its filesystems, re-requesting its configuration
													data, remounting filesystems, and re-starting
													its webservers. Timeout for this is 30 seconds.
													If a timeout occurs, we power-cycle
												 */ 
#define PHASE_RESET_TIMEOUT 30

#define PHASE_FAULT		6 /*
													A fault was detected by the controller 
													(slave not responding but still in cardslot)
													The controller will attempt to send it a 'RESET' 
													message every 10 seconds to try and kick it.
													If the slave ressurects, it should send an
													AFP CONFIG request, and a state transition will
													occurr to the CONFIG phase 
													*/
#define PHASE_FAULT_TIMEOUT 10
